# Define pkgdocdir for releases that don't define it already
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

%global proton_minimum_version 0.6

Name:          qpid-dispatch
Version:       0.1
Release:       1%{?dist}.2
Summary:       Dispatch router for Qpid
License:       ASL 2.0
URL:           http://qpid.apache.org/
Source0:       http://www.apache.org/dist/qpid/dispatch/%{version}/qpid-dispatch-%{version}.tar.gz

Patch1: 01-Systemd-control-file-for-qdrouterd.patch

BuildRequires: qpid-proton-c-devel >= %{proton_minimum_version}
BuildRequires: python-devel
BuildRequires: cmake
BuildRequires: systemd

Requires:      qpid-proton-c%{?_isa} >= %{proton_minimum_version}
Requires:      python
Requires:      python-qpid-proton >= %{proton_minimum_version}


%description
%{summary}.

# ----------------
# libqpid-dispatch
# ----------------

%package -n libqpid-dispatch
Summary:  The Qpid Dispatch Router library
Requires: qpid-proton-c%{?_isa} >= %{proton_minimum_version}

%description -n libqpid-dispatch
%{summary}.


%files -n libqpid-dispatch
%{_libdir}/libqpid-dispatch.so.*
%{_exec_prefix}/lib/qpid-dispatch


%post -n libqpid-dispatch -p /sbin/ldconfig


%postun -n libqpid-dispatch -p /sbin/ldconfig

# ----------------------
# libqpid-dispatch-devel
# ----------------------

%package -n libqpid-dispatch-devel
Summary:  Development files for Qpid Dispatch
Requires: qpid-proton-c-devel >= %{proton_minimum_version}
Requires: libqpid-dispatch%{?_isa} = %{version}-%{release}


%description -n libqpid-dispatch-devel
%{summary}.


%files -n libqpid-dispatch-devel
%{_includedir}/qpid/dispatch.h
%{_includedir}/qpid/dispatch
%{_libdir}/libqpid-dispatch.so


%post -n libqpid-dispatch-devel -p /sbin/ldconfig

%postun -n libqpid-dispatch-devel -p /sbin/ldconfig

# --------------------
# qpid-dispatch-router
# --------------------

%package -n qpid-dispatch-router
Summary:  The Qpid Dispatch Router executable
Requires: libqpid-dispatch%{?_isa} = %{version}


Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description -n qpid-dispatch-router
%{summary}.


%files -n qpid-dispatch-router
%{_sbindir}/qdrouterd
%config(noreplace) %{_sysconfdir}/qpid-dispatch/qdrouterd.conf
%{_unitdir}/qdrouterd.service
%{_mandir}/man5/qdrouterd.conf.5*
%{_mandir}/man8/qdrouterd.8*


%pre -n qpid-dispatch-router
getent group qpidd >/dev/null || groupadd -r qpidd
getent passwd qpidd >/dev/null || \
  useradd -r -M -g qpidd -d %{_localstatedir}/lib/qpidd -s /sbin/nologin \
    -c "Owner of Qpidd Daemons" qpidd
exit 0


%post -n qpid-dispatch-router
%systemd_post qpid-dxrouterd.service


%preun -n qpid-dispatch-router
%systemd_preun qpid-dxrouterd.service

%postun -n qpid-dispatch-router
%systemd_postun_with_restart qpid-dxrouterd.service

# -------------------------
# qpid-dispatch-router-docs
# -------------------------

%package -n qpid-dispatch-router-docs
Summary:   Documentation for the Qpid Dispatch router
BuildArch: noarch


%description -n qpid-dispatch-router-docs
%{summary}.


%files -n qpid-dispatch-router-docs
%doc %{_pkgdocdir}

# -------------------
# qpid-dispatch-tools
# -------------------

%package -n qpid-dispatch-tools
Summary:  Tools for the Qpid Dispatch router


%description -n qpid-dispatch-tools
%{summary}.


%files -n qpid-dispatch-tools
%{_bindir}/qdstat
%{_bindir}/qdtest
%{_mandir}/man8/qdstat.8*

# ------------------
# prep/build/install
# ------------------

%prep
%setup -q

%patch1 -p1

%build
%cmake -DDOC_INSTALL_DIR=%{?_pkgdocdir} \
       -DCMAKE_BUILD_TYPE=ReleaseWithDebInfo \
       .


%install
%make_install

mkdir -p %{buildroot}/%{_unitdir}
install -pm 644 %{_builddir}/qpid-dispatch-%{version}/etc/qdrouterd.service \
                %{buildroot}/%{_unitdir}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%changelog
* Thu Jan 23 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1.2
- Put all subpackage sections above prep/build/install.
- Removed check and clean sections.
- Added remaining systemd macros.
- Made qpid-dispatch-router-docs a noarch package.


* Wed Jan 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1.1
- Added the systemd macros for post/preun/postun
- Moved prep/build/install/check/clean above package definitions.

* Mon Jan 20 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1
- Initial packaging of the codebase.
